@@ -118,7 +118,7 @@ int main()
 
         assert(c0.empty());
     }
-#if __cplusplus >= 201103L
+#if TEST_STD_VER >= 11
     {
         typedef int P;
         typedef min_allocator<int> A;
