@@ -55,4 +55,10 @@ int main()
     assert(s.get_deleter().state() == 5);
     }
     assert(A::count == 0);
+    {
+    Deleter d;
+    std::unique_ptr<A[], Deleter> s(nullptr, d);
+    assert(s.get() == nullptr);
+    assert(s.get_deleter().state() == 5);
+    }
 }
